---
layout: page
title: Narrative Levels
index: -2
add_to_menu: true
---

Narrative levels are omnipresent in the narrative. But not only the phenomenon  is diverse, also it’s conceptions and definitions vary widely. E.g., one approach uses narrative levels to describe *embedded narratives*, which are stories in stories. They emerge if one narrator narrates another one. This narrated narrator tells an *embedded story*. Probably the most well-known example for narrative framing of this kind is the book [Arabian Nights](https://en.m.wikipedia.org/wiki/One_Thousand_and_One_Nights), in which Scheherazade tells her husband a new story every night. 

The most ordinary level distribution of embedded narratives looks like this: 

<!-- 
\setmainfont{Open Sans}
\begin{tikzpicture}
\node at (-0.5,0) {text};
\draw [->] (0,0) -- (14,0);
\draw (4,-0.1) -- (4,0.1);
\draw (10,-0.1) -- (10,0.1);
\node at (2,0.5) {\small narrator 1 (frame story)};
\node at (7,0.5) {\small narrator 2 (embedded story)};
\node at (12,0.5) {\small narrator 1 (frame story)};
\node at (4,-0.5) {\footnotesize level change};
\node at (10,-0.5) {\footnotesize level change};
\end{tikzpicture}

-->

<div style="margin-top:20px;margin-bottom:2em;">
<img src="{{site.baseurl}}/assets/narrative-levels/image-1.png" width="100%" />
<p class="caption">Figure 1: Ordinary level distribution</p>
</div>

However, the definitions of narrative levels are manifold and differ in scope. Sometimes the criterion of level change is not related to a full story any more, as it was originally introduced by Genette ([1972] 1980: 227-231). E.g., Ryan discusses narrative levels in the context of crossing boundaries in fictional worlds. In one case, so called illocutionary boundaries are crossed, when the fictional speaker changes, but they both refer to the same fictional reality (Ryan 1991: 175-177). If the narrator narrates a dialogue of two characters in direct speech, the level-distribution would look like this: 

<!--
\setmainfont{Open Sans}
\begin{tikzpicture}
\node at (-0.5,0) {text};
\draw [->] (0,0) -- (14,0);
\draw (2,-0.1) -- (2,0.1);
\draw (4,-0.1) -- (4,0.1);
\draw (6,-0.1) -- (6,0.1);
\draw (10,-0.1) -- (10,0.1);
\node at (1,0.5) {\small narrator};
\node at (3,0.5) {\small character A};
\node at (5,0.5) {\small character B};
\node at (8,0.5) {\small character A};
\node at (12,0.5) {\small narrator};
\node at (2,-0.5) {\footnotesize level change};
\node at (4,-0.5) {\footnotesize level change};
\node at (6,-0.5) {\footnotesize level change};
\node at (10,-0.5) {\footnotesize level change};
\end{tikzpicture}
-->

<div style="margin-top:20px;margin-bottom:2em;">
<img src="{{site.baseurl}}/assets/narrative-levels/image-2.png" width="100%" />
<p class="caption">Figure 2: Actual crossing of illocutionary boundaries</p>
</div>


Even if the dialogue is not considered as an embedded narration, there definitely is an illocutionary change of speaker (from narrator to character A and from character A to character B) that might give reason to assume level changes. **We want to encourage the participants** of the shared task to make use of this conceptual openness, and **to define an own understanding of “narrative level”**.

The following questions can help you to sharpen your understanding of narrative levels: 

- Does the change of speaker (narrator or character) necessarily imply a narrative level change?
- Do all characters of a certain story appear on the same narrative level? 
- Can embedded stories also be frame stories? 
- Can frame stories be embedded stories? 
- Must frame stories be un-embedded stories? 
- Can a text have more than one frame story? 
- Can a single character be both an embedded story narrator and part of this embedded story? (cf. for similar questions [Jahn, 2017](http://www.uni-koeln.de/~ame02/pppn.htm#N2.4))

The following list provides some narratological research literature into narrative levels as a starting point. 

## Further Reading

### Introductory

- Jahn, Manfred.  „N2.4. Narrative Levels“. In: *Manfred Jahn. Narratology: A Guide to the Theory of Narrative*. English Department, University of Cologne, 2017. [URL](http://www.uni-koeln.de/~ame02/pppn.htm#N2.4).
- Nelles, William. „Embedding“. In: David Herman, Manfred Jahn, and Marie-Laure Ryan (eds.). *Routledge Encyclopedia of Narrative Theory*. London; New York: Routledge, 2005. 134-135.
- Pier, John. „Narrative Levels (revised version; uploaded 23 April 2014)“. In: Peter Hühn, John Pier, Wolf Schmid, and Jörg Schönert (.). *the living handbook of narratology*. Hamburg: Hamburg University Press, 22. August 2014. [URL](http://www.lhn.uni-hamburg.de/article/narrative-levels-revised-version-uploaded-23-april-2014).

### Basics

- Genette, Gérard. Narrative Discourse. An Essay in Method. Ithaca 1980. (Original in French: Figures III. Paris 1972). 227-237
- Genette, Gérard. Die Erzählung. München: Fink, 2010, 147-154.
- Lahn, Silke, und Jan Christoph Meister. Einführung in die Erzähltextanalyse. Stuttgart: J.B. Metzler, 2008, 79-92.
- Martínez, Matías, und Michael Scheffel. Einführung in die Erzähltheorie. München 2003, 75-80.
- Neumann, Birgit, und Ansgar Nünning. „Metanarration and Metafiction“.  In: Peter Hühn, John Pier, Wolf Schmid, and Jörg Schönert (eds.). *the living handbook of narratology*. Hamburg: Hamburg University Press, 3. Dezember 2012. [URL](http://www.lhn.uni-hamburg.de/article/metanarration-and-metafiction).
- Ryan, Marie-Laure. Possible Worlds, Artificial Intelligence, and Narrative Theory. Bloomington: Indiana University Press, 1991. 175-177

### Advanced

- Lämmert, Eberhard. „Das Gefüge der Handlungsstränge“. In: Lämmert, Eberhard. *Bauformen des Erzählens*. Stuttgart: Metzler, 1955. 43-67
- Mani, Inderjeet. „Computational Narratology“. In: Peter Hühn, John Pier, Wolf Schmid, and Jörg Schönert (eds.). *the living handbook of narratology*. Hamburg: Hamburg University Press, 15. September 2013. [URL](http://www.lhn.uni-hamburg.de/article/computational-narratology).
- Nelles, William. Frameworks: Narrative Levels and Embedded Narrative. New York: P. Lang, 1997. 121-158
- Pier, John. „Metalepsis“. In: Peter Hühn, John Pier, Wolf Schmid, and Jörg Schönert (eds.). *the living handbook of narratology*. Hamburg: Hamburg University Press, 7. März 2012. [URL](http://www.lhn.uni-hamburg.de/article/metalepsis-revised-version-uploaded-13-july-2016).
- Rimmon-Kenan, Shlomith. „Narration: levels and voices.“ In: Rimmon-Kenan, Shlomith. *Narrative fiction*. 2. Aufl. London; New York: Routledge, 2004. 87-106
- Romberg, Bertil. Studies in the Narrative Technique of the First-Person Novel. Stockholm: Almqvist & Wiksell, 1962
